==> vtk-v3.1.2.zip: vtk-v3.1.2/common/vtkCellData.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkCellData.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2000 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkCellData.h"
#include "vtkObjectFactory.h"



//------------------------------------------------------------------------------
vtkCellData* vtkCellData::New()
{
  // First try to create the object from the vtkObjectFactory
  vtkObject* ret = vtkObjectFactory::CreateInstance("vtkCellData");
  if(ret)
    {
    return (vtkCellData*)ret;
    }
  // If the factory was unable to create the object, then create it here.
  return new vtkCellData;
}




void vtkCellData::NullCell (int ptId)
{
  if ( this->Scalars )
    {
    this->Scalars->GetData()->InsertTuple(ptId, this->Null4Tuple);
    }

  if ( this->Vectors )
    {
    this->Vectors->InsertVector(ptId,this->Null3Tuple);
    }

  if ( this->Normals )
    {
    this->Normals->InsertNormal(ptId,this->Null3Tuple);
    }

  if ( this->TCoords )
    {
    this->TCoords->InsertTCoord(ptId,this->Null3Tuple);
    }

  if ( this->Tensors )
    {
    this->Tensors->InsertTensor(ptId,(this->NullTensor));
    }

  if ( this->FieldData )
    {
    this->FieldData->InsertTuple(ptId,this->NullTuple);
    }

}

void vtkCellData::PrintSelf(ostream& os, vtkIndent indent)
{
  vtkDataSetAttributes::PrintSelf(os,indent);
}

==> vtk-v3.2.0.zip: vtk-v3.2.0/common/vtkCellData.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkCellData.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkCellData.h"
#include "vtkObjectFactory.h"



//------------------------------------------------------------------------------
vtkCellData* vtkCellData::New()
{
  // First try to create the object from the vtkObjectFactory
  vtkObject* ret = vtkObjectFactory::CreateInstance("vtkCellData");
  if(ret)
    {
    return (vtkCellData*)ret;
    }
  // If the factory was unable to create the object, then create it here.
  return new vtkCellData;
}




void vtkCellData::NullCell (int ptId)
{
  if ( this->Scalars )
    {
    this->Scalars->GetData()->InsertTuple(ptId, this->Null4Tuple);
    }

  if ( this->Vectors )
    {
    this->Vectors->InsertVector(ptId,this->Null3Tuple);
    }

  if ( this->Normals )
    {
    this->Normals->InsertNormal(ptId,this->Null3Tuple);
    }

  if ( this->TCoords )
    {
    this->TCoords->InsertTCoord(ptId,this->Null3Tuple);
    }

  if ( this->Tensors )
    {
    this->Tensors->InsertTensor(ptId,(this->NullTensor));
    }

  if ( this->FieldData )
    {
    this->FieldData->InsertTuple(ptId,this->NullTuple);
    }

}

void vtkCellData::PrintSelf(ostream& os, vtkIndent indent)
{
  vtkDataSetAttributes::PrintSelf(os,indent);
}
